@@ -83,7 +83,7 @@ c//////
 c      logical deb
 c      common /cdebug/ deb
 c/////////
-ccc c#define DEBUG 1
+cc      cc#define DEBUG 1
 
 
 
@@ -93,6 +93,7 @@ ccc c#define DEBUG 1
 cc      integer icon
 
 #if DEBUG == 1
+c      deb=.true.
       call checkstat('before fixModel')
 #endif
 
@@ -291,7 +292,7 @@ c                  the first collision point. or ptcl goes streight
      *     ObsPlane .ne. 3) then
          call csetMinTime(aTrack)
       else
-c         MovedTrack.t = 0.     ! bug bef uv6.09
+c         MovedTrack.t = 0.     ! bug bef uv6.09 ;;; but why commentout ??? 
       endif
       end
 
@@ -469,7 +470,7 @@ c     **************************** cfixProc **********
 c     
       integer i, jcut
 c     
-      minlen = Infty
+       minlen = Infty + Infty
 
 c              get vertical height
        h = TrackBefMove.pos.height
@@ -478,8 +479,6 @@ c              get vertical height
 c              convert kg/m2 into length
             if(NumberOfInte .eq. 1 .or.
      *        IntInfArray(i).thickness .ne. Infty) then
-c               call cthick2len(h, TrackBefMove.vec.coszenith, 
-c     *         IntInfArray(i).thickness, leng, t, jcut)
                call cthick2len(TrackBefMove,
      *         IntInfArray(i).thickness, leng, t, jcut) 
                if(leng .le. 0.) then
@@ -492,7 +491,7 @@ c     *         IntInfArray(i).thickness, leng, t, jcut)
             leng = IntInfArray(i).length
             jcut = 0
          endif
-         if(leng .le. minlen) then
+         if(leng .lt. minlen) then
             if(jcut .ne. 0) then
                MoveStat = Truncated
             else
@@ -505,15 +504,15 @@ c     *         IntInfArray(i).thickness, leng, t, jcut)
          endif
       enddo
 c      if(leng .ge. minlen) then  !   bug in 6.00
-      if(leng .ge. Infty) then  
-         ProcessNo = 1
-         IntInfArray(1).length = 1.e5
-      endif         
+c      if(leng .ge. Infty) then  
+c         ProcessNo = 1
+c         IntInfArray(1).length = 1.e5
+c      endif         
       if(IntInfArray(ProcessNo).decay .or. jcut .ne. 0) then
 c         In the case  of muon, if individual knockon process  
 c       is neglected (by parameter setting or with high Emin)
 c       the length could be quite large (say, 6000  km).
-c       and result in the  error in the next call.
+c       and results in error in the next call.
 c       To avoid that, we cut the path here
 c
          if( TrackBefMove.vec.coszenith .lt. 0.) then
@@ -543,8 +542,12 @@ c        an observation depth.
       real*8 leng, thick
 c
       call cmaxMovLen(leng, thick)
-
-
+c//////////
+c      write(*,*) ' -- maxlen=',leng, ' thick=',thick,
+c     *  ' proce no=',ProcessNo, ' proc=',
+c     *    IntInfArray(ProcessNo).process,
+c     * ' int leng=',  IntInfArray(ProcessNo).length 
+c////////////
       if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
